@@ -1,16 +1,6 @@
-# Copyright 2013 Hynek Schlawack
-#
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
-#
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
+# This file is dual licensed under the terms of the Apache License, Version
+# 2.0, and the MIT License.  See the LICENSE file in the root of this
+# repository for complete details.
 
 from __future__ import absolute_import, division, print_function
 
@@ -21,10 +11,10 @@ from structlog._loggers import ReturnLogger
 
 class TestLogger(object):
     def log(self, msg):
-        return 'log', msg
+        return "log", msg
 
     def gol(self, msg):
-        return 'gol', msg
+        return "gol", msg
 
 
 class TestGenericBoundLogger(object):
@@ -37,9 +27,12 @@ class TestGenericBoundLogger(object):
             _CONFIG.default_processors,
             _CONFIG.default_context_class(),
         )
-        assert 'msg' not in b.__dict__
-        b.msg('foo')
-        assert 'msg' in b.__dict__
+
+        assert "msg" not in b.__dict__
+
+        b.msg("foo")
+
+        assert "msg" in b.__dict__
 
     def test_proxies_anything(self):
         """
@@ -51,5 +44,6 @@ class TestGenericBoundLogger(object):
             _CONFIG.default_processors,
             _CONFIG.default_context_class(),
         )
-        assert 'log', 'foo' == b.log('foo')
-        assert 'gol', 'bar' == b.gol('bar')
+
+        assert "log", "foo" == b.log("foo")
+        assert "gol", "bar" == b.gol("bar")
